==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGridRowDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowDirectiveDescriptionMetadata } from "./WebRowDirectiveDescriptionMetadata";
import { WebGridRowDescription } from "./WebGridRowDescription";
/**
 * @hidden
 */
var WebGridRowDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridRowDescriptionMetadata, _super);
    function WebGridRowDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridRowDescriptionMetadata.b = function (a) {
        if (WebGridRowDescriptionMetadata.a == null) {
            WebGridRowDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridRowDescriptionMetadata.c(WebGridRowDescriptionMetadata.a);
        }
        if (a.j(WebGridRowDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridRowDescriptionMetadata.a);
    };
    WebGridRowDescriptionMetadata.c = function (a) {
        WebRowDirectiveDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GridRow");
        a.item("__packageNameWC", "String:grids");
    };
    WebGridRowDescriptionMetadata.d = function (a) {
        WebGridRowDescriptionMetadata.b(a);
        a.aa("WebGridRow", function () { return new WebGridRowDescription(); });
        a.z("WebGridRow", WebGridRowDescriptionMetadata.a);
    };
    WebGridRowDescriptionMetadata.$t = markType(WebGridRowDescriptionMetadata, 'WebGridRowDescriptionMetadata');
    WebGridRowDescriptionMetadata.a = null;
    return WebGridRowDescriptionMetadata;
}(Base));
export { WebGridRowDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGridRowDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowDirectiveDescriptionMetadata } from "./WebRowDirectiveDescriptionMetadata";
import { WebGridRowDescription } from "./WebGridRowDescription";
/**
 * @hidden
 */
var WebGridRowDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridRowDescriptionMetadata, _super);
    function WebGridRowDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridRowDescriptionMetadata.b = function (a) {
        if (WebGridRowDescriptionMetadata.a == null) {
            WebGridRowDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridRowDescriptionMetadata.c(WebGridRowDescriptionMetadata.a);
        }
        if (a.k(WebGridRowDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridRowDescriptionMetadata.a);
    };
    WebGridRowDescriptionMetadata.c = function (a) {
        WebRowDirectiveDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GridRow");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        if (a.containsKey("__skipSuffix")) {
            a.removeItem("__skipSuffix");
        }
    };
    WebGridRowDescriptionMetadata.d = function (a) {
        WebGridRowDescriptionMetadata.b(a);
        a.ac("WebGridRow", function () { return new WebGridRowDescription(); });
        a.ab("WebGridRow", WebGridRowDescriptionMetadata.a);
    };
    WebGridRowDescriptionMetadata.$t = markType(WebGridRowDescriptionMetadata, 'WebGridRowDescriptionMetadata');
    WebGridRowDescriptionMetadata.a = null;
    return WebGridRowDescriptionMetadata;
}(Base));
export { WebGridRowDescriptionMetadata };
